@@ -98,6 +98,10 @@ auto_tag_thread = true
 # Allow users to edit their own messages
 edit_message = true
 
+[features.slack]
+# Add emoji reaction when message is received (requires reactions:write OAuth scope)
+reaction_on_message_received = false
+
 # Authorize users to spontaneously upload files with messages
 [features.spontaneous_file_upload]
     enabled = true
@@ -121,6 +125,9 @@ edit_message = true
 [features.mcp.sse]
     enabled = true
 
+[features.mcp.streamable-http]
+    enabled = true
+
 [features.mcp.stdio]
     enabled = true
     # Only the executables in the allow list can be used for MCP stdio server.
@@ -256,16 +263,29 @@ class McpSseFeature(DataClassJsonMixin):
     enabled: bool = True
 
 
+@dataclass
+class McpStreamableHttpFeature(DataClassJsonMixin):
+    enabled: bool = True
+
+
 @dataclass
 class McpStdioFeature(DataClassJsonMixin):
     enabled: bool = True
     allowed_executables: Optional[list[str]] = None
 
 
+@dataclass
+class SlackFeature(DataClassJsonMixin):
+    reaction_on_message_received: bool = False
+
+
 @dataclass
 class McpFeature(DataClassJsonMixin):
     enabled: bool = False
     sse: McpSseFeature = Field(default_factory=McpSseFeature)
+    streamable_http: McpStreamableHttpFeature = Field(
+        default_factory=McpStreamableHttpFeature
+    )
     stdio: McpStdioFeature = Field(default_factory=McpStdioFeature)
 
 
@@ -274,6 +294,7 @@ class FeaturesSettings(DataClassJsonMixin):
     spontaneous_file_upload: Optional[SpontaneousFileUploadFeature] = None
     audio: Optional[AudioFeature] = Field(default_factory=AudioFeature)
     mcp: McpFeature = Field(default_factory=McpFeature)
+    slack: SlackFeature = Field(default_factory=SlackFeature)
     latex: bool = False
     user_message_autoscroll: bool = True
     unsafe_allow_html: bool = False
@@ -294,7 +315,6 @@ class UISettings(DataClassJsonMixin):
     name: str
     description: str = ""
     cot: Literal["hidden", "tool_call", "full"] = "full"
-    font_family: Optional[str] = None
     default_theme: Optional[Literal["light", "dark"]] = "dark"
     layout: Optional[Literal["default", "wide"]] = "default"
     default_sidebar_state: Optional[Literal["open", "closed"]] = "open"
