@@ -25,6 +25,7 @@ from fastapi import (
     UploadFile,
     status,
 )
+from fastapi.middleware.gzip import GZipMiddleware
 from fastapi.responses import FileResponse, HTMLResponse, JSONResponse, RedirectResponse
 from fastapi.security import OAuth2PasswordRequestForm
 from starlette.datastructures import URL
@@ -216,6 +217,8 @@ app.add_middleware(
     allow_headers=["*"],
 )
 
+app.add_middleware(GZipMiddleware)
+
 # config.run.root_path is only set when started with --root-path. Not on submounts.
 router = APIRouter(prefix=config.run.root_path)
 
@@ -712,7 +715,7 @@ async def get_user(current_user: UserParam) -> GenericUser:
 
 
 _language_pattern = (
-    "^[a-zA-Z]{2,3}(-[a-zA-Z0-9]{2,3})?(-[a-zA-Z0-9]{2,8})?(-x-[a-zA-Z0-9]{1,8})?$"
+    "^[a-zA-Z]{2,3}(-[a-zA-Z0-9]{2,4})?(-[a-zA-Z0-9]{2,8})?(-x-[a-zA-Z0-9]{1,8})?$"
 )
 
 
@@ -1106,9 +1109,16 @@ async def connect_mcp(
         get_default_environment,
         stdio_client,
     )
+    from mcp.client.streamable_http import streamablehttp_client
 
     from chainlit.context import init_ws_context
-    from chainlit.mcp import SseMcpConnection, StdioMcpConnection, validate_mcp_command
+    from chainlit.mcp import (
+        HttpMcpConnection,
+        McpConnection,
+        SseMcpConnection,
+        StdioMcpConnection,
+        validate_mcp_command,
+    )
     from chainlit.session import WebsocketSession
 
     session = WebsocketSession.get_by_id(payload.sessionId)
@@ -1136,6 +1146,7 @@ async def connect_mcp(
 
         try:
             exit_stack = AsyncExitStack()
+            mcp_connection: McpConnection
 
             if payload.clientType == "sse":
                 if not config.features.mcp.sse.enabled:
@@ -1144,10 +1155,17 @@ async def connect_mcp(
                         detail="SSE MCP is not enabled",
                     )
 
-                mcp_connection = SseMcpConnection(url=payload.url, name=payload.name)  # type: SseMcpConnection
+                mcp_connection = SseMcpConnection(
+                    url=payload.url,
+                    name=payload.name,
+                    headers=getattr(payload, "headers", None),
+                )
 
                 transport = await exit_stack.enter_async_context(
-                    sse_client(url=mcp_connection.url)
+                    sse_client(
+                        url=mcp_connection.url,
+                        headers=mcp_connection.headers,
+                    )
                 )
             elif payload.clientType == "stdio":
                 if not config.features.mcp.stdio.enabled:
@@ -1157,24 +1175,43 @@ async def connect_mcp(
                     )
 
                 env_from_cmd, command, args = validate_mcp_command(payload.fullCommand)
-                mcp_connection = StdioMcpConnection(  # type: ignore[no-redef]
+                mcp_connection = StdioMcpConnection(
                     command=command, args=args, name=payload.name
-                )  # type: StdioMcpConnection
+                )
 
                 env = get_default_environment()
                 env.update(env_from_cmd)
                 # Create the server parameters
                 server_params = StdioServerParameters(
-                    command=command,
-                    args=args,
-                    env=env,
+                    command=command, args=args, env=env
                 )
 
                 transport = await exit_stack.enter_async_context(
                     stdio_client(server_params)
                 )
 
-            read, write = transport
+            elif payload.clientType == "streamable-http":
+                if not config.features.mcp.streamable_http.enabled:
+                    raise HTTPException(
+                        status_code=400,
+                        detail="HTTP MCP is not enabled",
+                    )
+                mcp_connection = HttpMcpConnection(
+                    url=payload.url,
+                    name=payload.name,
+                    headers=getattr(payload, "headers", None),
+                )
+                transport = await exit_stack.enter_async_context(
+                    streamablehttp_client(
+                        url=mcp_connection.url,
+                        headers=mcp_connection.headers,
+                    )
+                )
+
+            # The transport can return (read, write) for stdio, sse
+            # Or (read, write, get_session_id) for streamable-http
+            # We are only interested in the read and write streams here.
+            read, write = transport[:2]
 
             mcp_session: ClientSession = await exit_stack.enter_async_context(
                 ClientSession(
@@ -1214,7 +1251,13 @@ async def connect_mcp(
                 "command": payload.fullCommand
                 if payload.clientType == "stdio"
                 else None,
-                "url": payload.url if payload.clientType == "sse" else None,
+                "url": getattr(payload, "url", None)
+                if payload.clientType in ["sse", "streamable-http"]
+                else None,
+                # Include optional headers for SSE and streamable-http connections
+                "headers": getattr(payload, "headers", None)
+                if payload.clientType in ["sse", "streamable-http"]
+                else None,
             },
         }
     )
